@@ -2,20 +2,19 @@
 /*  GMime
  *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public License
- *  as published by the Free Software Foundation; either version 2.1
- *  of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This library is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free
- *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -135,7 +134,7 @@ filter_filter (GMimeFilter *filter, char *in, size_t len, size_t prespace,
 		}
 	}
 	
-	g_mime_filter_backup (filter, (char *) last, inptr - last);
+	g_mime_filter_backup (filter, last, inptr - last);
 	
 	*out = filter->outbuf;
 	*outlen = outptr - filter->outbuf;
@@ -166,11 +165,11 @@ filter_reset (GMimeFilter *filter)
  * Returns a new strip filter.
  **/
 GMimeFilter *
-g_mime_filter_strip_new (void)
+g_mime_filter_strip_new ()
 {
 	GMimeFilterStrip *new;
 	
-	new = g_object_new (GMIME_TYPE_FILTER_STRIP, NULL);
+	new = g_object_new (GMIME_TYPE_FILTER_STRIP, NULL, NULL);
 	
 	return (GMimeFilter *) new;
 }
