@@ -1,21 +1,20 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public License
- *  as published by the Free Software Foundation; either version 2.1
- *  of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This library is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free
- *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -33,18 +32,8 @@
 #include "gmime-utils.h"
 #include "gmime-stream-mem.h"
 #include "gmime-table-private.h"
-#include "gmime-parse-utils.h"
 
 
-/**
- * SECTION: gmime-message
- * @title: GMimeMessage
- * @short_description: Messages
- * @see_also:
- *
- * A #GMimeMessage represents an rfc822 message.
- **/
-
 static void g_mime_message_class_init (GMimeMessageClass *klass);
 static void g_mime_message_init (GMimeMessage *message, GMimeMessageClass *klass);
 static void g_mime_message_finalize (GObject *object);
@@ -58,9 +47,8 @@ static void message_remove_header (GMimeObject *object, const char *header);
 static char *message_get_headers (GMimeObject *object);
 static ssize_t message_write_to_stream (GMimeObject *object, GMimeStream *stream);
 
-static void message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string);
+static void message_add_recipients_from_string (GMimeMessage *message, char *type, const char *string);
 
-static ssize_t write_structured (GMimeStream *stream, const char *name, const char *value);
 static ssize_t write_addrspec (GMimeStream *stream, const char *name, const char *value);
 static ssize_t write_received (GMimeStream *stream, const char *name, const char *value);
 static ssize_t write_subject (GMimeStream *stream, const char *name, const char *value);
@@ -155,7 +143,7 @@ g_mime_message_init (GMimeMessage *message, GMimeMessageClass *klass)
 	g_mime_header_register_writer (((GMimeObject *) message)->headers, "Subject", write_subject);
 	g_mime_header_register_writer (((GMimeObject *) message)->headers, "Received", write_received);
 	g_mime_header_register_writer (((GMimeObject *) message)->headers, "Message-Id", write_msgid);
-	g_mime_header_register_writer (((GMimeObject *) message)->headers, "References", write_structured);
+	g_mime_header_register_writer (((GMimeObject *) message)->headers, "References", write_addrspec);
 }
 
 static gboolean
@@ -208,6 +196,8 @@ struct _received_token {
 	token_skip_t skip;
 };
 
+extern void decode_lwsp   (const char **in);
+
 static void skip_atom     (const char **in);
 static void skip_domain   (const char **in);
 static void skip_addr     (const char **in);
@@ -424,11 +414,10 @@ static ssize_t
 write_received (GMimeStream *stream, const char *name, const char *value)
 {
 	struct _received_part *parts, *part, *tail;
-	const char *inptr, *lwsp = NULL;
+	const char *lwsp, *inptr;
 	ssize_t nwritten;
 	GString *str;
-	size_t len;
-	guint i;
+	int len, i;
 	
 	while (is_lwsp (*value))
 		value++;
@@ -448,7 +437,6 @@ write_received (GMimeStream *stream, const char *name, const char *value)
 		for (i = 0; i < G_N_ELEMENTS (received_tokens); i++) {
 			if (!strncmp (inptr, received_tokens[i].token, received_tokens[i].len)) {
 				if (inptr > part->start) {
-					g_assert (lwsp != NULL);
 					part->len = lwsp - part->start;
 					
 					part = g_alloca (sizeof (struct _received_part));
@@ -558,7 +546,7 @@ write_msgid (GMimeStream *stream, const char *name, const char *value)
 }
 
 static ssize_t
-write_structured (GMimeStream *stream, const char *name, const char *value)
+write_addrspec (GMimeStream *stream, const char *name, const char *value)
 {
 	char *unfolded, *folded;
 	ssize_t n;
@@ -573,29 +561,6 @@ write_structured (GMimeStream *stream, const char *name, const char *value)
 	return n;
 }
 
-static ssize_t
-write_addrspec (GMimeStream *stream, const char *name, const char *value)
-{
-	InternetAddressList *addrlist;
-	GString *str;
-	ssize_t n;
-	
-	str = g_string_new (name);
-	g_string_append (str, ": ");
-	
-	if (value && (addrlist = internet_address_parse_string (value))) {
-		internet_address_list_writer (addrlist, str);
-		internet_address_list_destroy (addrlist);
-	}
-	
-	g_string_append_c (str, '\n');
-	
-	n = g_mime_stream_write (stream, str->str, str->len);
-	g_string_free (str, TRUE);
-	
-	return n;
-}
-
 
 enum {
 	HEADER_FROM,
@@ -828,8 +793,8 @@ message_get_headers (GMimeObject *object)
 	}
 	
 	g_object_unref (stream);
-	g_byte_array_append (ba, (unsigned char *) "", 1);
-	str = (char *) ba->data;
+	g_byte_array_append (ba, "", 1);
+	str = ba->data;
 	g_byte_array_free (ba, FALSE);
 	
 	return str;
@@ -841,29 +806,24 @@ message_write_to_stream (GMimeObject *object, GMimeStream *stream)
 	GMimeMessage *message = (GMimeMessage *) object;
 	ssize_t nwritten, total = 0;
 	
-	if (message->mime_part) {
-		if (!g_mime_header_has_raw (message->mime_part->headers)) {
-			/* if the mime part has raw headers, then it contains the message
-			 * headers as well otherwise it doesn't, so write them now */
-			if ((nwritten = g_mime_header_write_to_stream (object->headers, stream)) == -1)
-				return -1;
-			
-			total += nwritten;
-			
-			if ((nwritten = g_mime_stream_write_string (stream, "MIME-Version: 1.0\n")) == -1)
-				return -1;
-			
-			total += nwritten;
-		}
-		
-		if ((nwritten = g_mime_object_write_to_stream (message->mime_part, stream)) == -1)
-			return -1;
-	} else {
+	if (!(message->mime_part && g_mime_header_has_raw (message->mime_part->headers))) {
+		/* write the content headers */
 		if ((nwritten = g_mime_header_write_to_stream (object->headers, stream)) == -1)
 			return -1;
 		
 		total += nwritten;
 		
+		if (message->mime_part) {
+			if ((nwritten = g_mime_stream_write_string (stream, "MIME-Version: 1.0\n")) == -1)
+				return -1;
+			
+			total += nwritten;
+		}
+	}
+	
+	if (message->mime_part) {
+		nwritten = g_mime_object_write_to_stream (message->mime_part, stream);
+	} else {
 		if ((nwritten = g_mime_stream_write (stream, "\n", 1)) == -1)
 			return -1;
 	}
@@ -891,7 +851,7 @@ g_mime_message_new (gboolean pretty_headers)
 	GMimeMessage *message;
 	int i;
 	
-	message = g_object_new (GMIME_TYPE_MESSAGE, NULL);
+	message = g_object_new (GMIME_TYPE_MESSAGE, NULL, NULL);
 	
 	if (pretty_headers) {
 		/* Populate with the "standard" rfc822 headers so we can have a standard order */
@@ -990,10 +950,12 @@ static void
 sync_recipient_header (GMimeMessage *message, const char *type)
 {
 	const InternetAddressList *recipients;
-	char *string;
 	
 	/* sync the specified recipient header */
-	if ((recipients = g_mime_message_get_recipients (message, type))) {
+	recipients = g_mime_message_get_recipients (message, type);
+	if (recipients) {
+		char *string;
+		
 		string = internet_address_list_to_string (recipients, TRUE);
 		g_mime_header_set (GMIME_OBJECT (message)->headers, type, string);
 		g_free (string);
@@ -1014,7 +976,7 @@ sync_recipient_header (GMimeMessage *message, const char *type)
  * #GMIME_RECIPIENT_TYPE_CC and #GMIME_RECIPIENT_TYPE_BCC.
  **/
 void
-g_mime_message_add_recipient (GMimeMessage *message, const char *type, const char *name, const char *address)
+g_mime_message_add_recipient (GMimeMessage *message, char *type, const char *name, const char *address)
 {
 	InternetAddressList *recipients;
 	InternetAddress *ia;
@@ -1032,25 +994,26 @@ g_mime_message_add_recipient (GMimeMessage *message, const char *type, const cha
 	recipients = internet_address_list_append (recipients, ia);
 	internet_address_unref (ia);
 	
-	g_hash_table_insert (message->recipients, (char *) type, recipients);
+	g_hash_table_insert (message->recipients, type, recipients);
 	sync_recipient_header (message, type);
 }
 
 
 static void
-message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string)
+message_add_recipients_from_string (GMimeMessage *message, char *type, const char *string)
 {
 	InternetAddressList *recipients, *addrlist;
 	
 	recipients = g_hash_table_lookup (message->recipients, type);
 	g_hash_table_remove (message->recipients, type);
 	
-	if ((addrlist = internet_address_parse_string (string))) {
+	addrlist = internet_address_parse_string (string);
+	if (addrlist) {
 		recipients = internet_address_list_concat (recipients, addrlist);
 		internet_address_list_destroy (addrlist);
 	}
 	
-	g_hash_table_insert (message->recipients, (char *) type, recipients);
+	g_hash_table_insert (message->recipients, type, recipients);
 }
 
 
@@ -1067,7 +1030,7 @@ message_add_recipients_from_string (GMimeMessage *message, const char *type, con
  * specified in rfc822.
  **/
 void
-g_mime_message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string)
+g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, const char *string)
 {
 	g_return_if_fail (GMIME_IS_MESSAGE (message));
 	g_return_if_fail (type != NULL);
@@ -1101,50 +1064,6 @@ g_mime_message_get_recipients (GMimeMessage *message, const char *type)
 }
 
 
-static const char *recipient_types[] = {
-	GMIME_RECIPIENT_TYPE_TO,
-	GMIME_RECIPIENT_TYPE_CC,
-	GMIME_RECIPIENT_TYPE_BCC
-};
-
-/**
- * g_mime_message_get_all_recipients:
- * @message: MIME Message
- *
- * Gets the complete list of recipients for @message.
- *
- * Returns a newly allocated #InternetAddressList containing all
- * recipients of the message.
- **/
-InternetAddressList *
-g_mime_message_get_all_recipients (GMimeMessage *message)
-{
-	InternetAddressList *list, *tail, *node, *recipients;
-	guint i;
-	
-	g_return_val_if_fail (GMIME_IS_MESSAGE (message), NULL);
-	
-	list = NULL;
-	tail = (InternetAddressList *) &list;
-	
-	for (i = 0; i < G_N_ELEMENTS (recipient_types); i++) {
-		recipients = g_hash_table_lookup (message->recipients, recipient_types[i]);
-		while (recipients != NULL) {
-			internet_address_ref (recipients->address);
-			node = g_new (InternetAddressList, 1);
-			node->address = recipients->address;
-			node->next = NULL;
-			tail->next = node;
-			tail = node;
-			
-			recipients = recipients->next;
-		}
-	}
-	
-	return list;
-}
-
-
 /**
  * g_mime_message_set_subject:
  * @message: MIME Message
@@ -1392,10 +1311,8 @@ g_mime_message_set_mime_part (GMimeMessage *message, GMimeObject *mime_part)
 	g_object_ref (mime_part);
 	g_mime_header_set_raw (mime_part->headers, NULL);
 	
-	if (message->mime_part) {
-		g_mime_header_set_raw (message->mime_part->headers, NULL);
+	if (message->mime_part)
 		g_object_unref (message->mime_part);
-	}
 	
 	message->mime_part = mime_part;
 }
@@ -1411,7 +1328,7 @@ g_mime_message_set_mime_part (GMimeMessage *message, GMimeObject *mime_part)
  * WARNING: This interface is deprecated. Use
  * g_mime_object_write_to_stream() instead.
  *
- * Returns %-1 on fail.
+ * Returns -1 on fail.
  **/
 ssize_t
 g_mime_message_write_to_stream (GMimeMessage *message, GMimeStream *stream)
@@ -1536,8 +1453,6 @@ handle_multipart_mixed (GMimeMultipart *multipart, gboolean want_plain, gboolean
  * Attempts to get the body of the message in the preferred format
  * specified by @want_plain.
  *
- * WARNING: This interface is deprecated.
- *
  * Returns the prefered form of the message body. Sets the value of
  * @is_html to %TRUE if the part returned is in HTML format, otherwise
  * %FALSE.
