@@ -1,21 +1,20 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public License
- *  as published by the Free Software Foundation; either version 2.1
- *  of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This library is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free
- *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -28,7 +27,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include <errno.h>
 
 #include "gmime-multipart.h"
 #include "gmime-utils.h"
@@ -36,17 +34,6 @@
 
 #define d(x)
 
-
-/**
- * SECTION: gmime-multipart
- * @title: GMimeMultipart
- * @short_description: MIME multiparts
- * @see_also:
- *
- * A #GMimeMultipart represents all multipart MIME container parts.
- **/
-
-
 /* GObject class methods */
 static void g_mime_multipart_class_init (GMimeMultipartClass *klass);
 static void g_mime_multipart_init (GMimeMultipart *multipart, GMimeMultipartClass *klass);
@@ -90,7 +77,7 @@ g_mime_multipart_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimeMultipart),
-			0,    /* n_preallocs */
+			16,   /* n_preallocs */
 			(GInstanceInitFunc) g_mime_multipart_init,
 		};
 		
@@ -243,11 +230,8 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 	GMimeObject *part;
 	GList *node;
 	
-	/* make sure a boundary is set unless we are writing out a raw
-	 * header (in which case it should already be set... or if
-	 * not, then it's a broken multipart and so we don't want to
-	 * alter it or we'll completely break the output) */
-	if (!multipart->boundary && !g_mime_header_has_raw (object->headers))
+	/* make sure a boundary is set */
+	if (!multipart->boundary)
 		g_mime_multipart_set_boundary (multipart, NULL);
 	
 	/* write the content headers */
@@ -289,13 +273,10 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 		node = node->next;
 	}
 	
-	/* write the end-boundary (but only if a boundary is set) */
-	if (multipart->boundary) {
-		if ((nwritten = g_mime_stream_printf (stream, "\n--%s--\n", multipart->boundary)) == -1)
-			return -1;
-		
-		total += nwritten;
-	}
+	if ((nwritten = g_mime_stream_printf (stream, "\n--%s--\n", multipart->boundary)) == -1)
+		return -1;
+	
+	total += nwritten;
 	
 	/* write the postface */
 	if (multipart->postface) {
@@ -319,12 +300,12 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
  * multipart/mixed.
  **/
 GMimeMultipart *
-g_mime_multipart_new (void)
+g_mime_multipart_new ()
 {
 	GMimeMultipart *multipart;
 	GMimeContentType *type;
 	
-	multipart = g_object_new (GMIME_TYPE_MULTIPART, NULL);
+	multipart = g_object_new (GMIME_TYPE_MULTIPART, NULL, NULL);
 	
 	type = g_mime_content_type_new ("multipart", "mixed");
 	g_mime_object_set_content_type (GMIME_OBJECT (multipart), type);
@@ -349,7 +330,7 @@ g_mime_multipart_new_with_subtype (const char *subtype)
 	GMimeMultipart *multipart;
 	GMimeContentType *type;
 	
-	multipart = g_object_new (GMIME_TYPE_MULTIPART, NULL);
+	multipart = g_object_new (GMIME_TYPE_MULTIPART, NULL, NULL);
 	
 	type = g_mime_content_type_new ("multipart", subtype ? subtype : "mixed");
 	g_mime_object_set_content_type (GMIME_OBJECT (multipart), type);
@@ -645,10 +626,8 @@ g_mime_multipart_get_number (GMimeMultipart *multipart)
 
 
 static void
-read_random_pool (unsigned char *buffer, size_t bytes)
+read_random_pool (char *buffer, size_t bytes)
 {
-	size_t nread = 0;
-	ssize_t n;
 	int fd;
 	
 	if ((fd = open ("/dev/urandom", O_RDONLY)) == -1) {
@@ -656,17 +635,7 @@ read_random_pool (unsigned char *buffer, size_t bytes)
 			return;
 	}
 	
-	do {
-		do {
-			n = read (fd, (char *) buffer + nread, bytes - nread);
-		} while (n == -1 && errno == EINTR);
-		
-		if (n == -1 || n == 0)
-			break;
-		
-		nread += n;
-	} while (nread < bytes);
-	
+	read (fd, buffer, bytes);
 	close (fd);
 }
 
@@ -677,14 +646,14 @@ multipart_set_boundary (GMimeMultipart *multipart, const char *boundary)
 	
 	if (!boundary) {
 		/* Generate a fairly random boundary string. */
-		unsigned char digest[16], *p;
-		guint32 save = 0;
-		int state = 0;
+		char digest[16], *p;
+		int state, save;
 		
 		read_random_pool (digest, 16);
 		
 		strcpy (bbuf, "=-");
-		p = (unsigned char *) bbuf + 2;
+		p = bbuf + 2;
+		state = save = 0;
 		p += g_mime_utils_base64_encode_step (digest, 16, p, &state, &save);
 		*p = '\0';
 		
