@@ -1,21 +1,20 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public License
- *  as published by the Free Software Foundation; either version 2.1
- *  of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This library is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free
- *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -42,17 +41,6 @@
 
 #define d(x)
 
-
-/**
- * SECTION: gmime-part
- * @title: GMimePart
- * @short_description: MIME parts
- * @see_also:
- *
- * A #GMimePart represents any MIME leaf part (meaning it has no
- * sub-parts).
- **/
-
 /* GObject class methods */
 static void g_mime_part_class_init (GMimePartClass *klass);
 static void g_mime_part_init (GMimePart *mime_part, GMimePartClass *klass);
@@ -91,7 +79,7 @@ g_mime_part_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimePart),
-			0,    /* n_preallocs */
+			16,   /* n_preallocs */
 			(GInstanceInitFunc) g_mime_part_init,
 		};
 		
@@ -441,12 +429,12 @@ mime_part_write_to_stream (GMimeObject *object, GMimeStream *stream)
  * text/plain.
  **/
 GMimePart *
-g_mime_part_new (void)
+g_mime_part_new ()
 {
 	GMimePart *mime_part;
 	GMimeContentType *type;
 	
-	mime_part = g_object_new (GMIME_TYPE_PART, NULL);
+	mime_part = g_object_new (GMIME_TYPE_PART, NULL, NULL);
 	
 	type = g_mime_content_type_new ("text", "plain");
 	g_mime_object_set_content_type (GMIME_OBJECT (mime_part), type);
@@ -470,7 +458,7 @@ g_mime_part_new_with_type (const char *type, const char *subtype)
 	GMimePart *mime_part;
 	GMimeContentType *content_type;
 	
-	mime_part = g_object_new (GMIME_TYPE_PART, NULL);
+	mime_part = g_object_new (GMIME_TYPE_PART, NULL, NULL);
 	
 	content_type = g_mime_content_type_new (type, subtype);
 	g_mime_object_set_content_type (GMIME_OBJECT (mime_part), content_type);
@@ -604,8 +592,7 @@ g_mime_part_set_content_md5 (GMimePart *mime_part, const char *content_md5)
 	GMimeStreamFilter *filtered_stream;
 	GMimeFilter *md5_filter;
 	GMimeStream *stream;
-	guint32 save = 0;
-	int state = 0;
+	int state, save;
 	size_t len;
 	
 	g_return_if_fail (GMIME_IS_PART (mime_part));
@@ -641,9 +628,10 @@ g_mime_part_set_content_md5 (GMimePart *mime_part, const char *content_md5)
 		g_mime_filter_md5_get_digest ((GMimeFilterMd5 *) md5_filter, digest);
 		g_object_unref (md5_filter);
 		
+		state = save = 0;
 		len = g_mime_utils_base64_encode_close (digest, 16, b64digest, &state, &save);
 		b64digest[len] = '\0';
-		g_strstrip ((char *) b64digest);
+		g_strstrip (b64digest);
 		
 		content_md5 = (const char *) b64digest;
 	}
@@ -670,8 +658,7 @@ g_mime_part_verify_content_md5 (GMimePart *mime_part)
 	GMimeStreamFilter *filtered_stream;
 	GMimeFilter *md5_filter;
 	GMimeStream *stream;
-	guint32 save = 0;
-	int state = 0;
+	int state, save;
 	size_t len;
 	
 	g_return_val_if_fail (GMIME_IS_PART (mime_part), FALSE);
@@ -706,11 +693,12 @@ g_mime_part_verify_content_md5 (GMimePart *mime_part)
 	g_mime_filter_md5_get_digest ((GMimeFilterMd5 *) md5_filter, digest);
 	g_object_unref (md5_filter);
 	
+	state = save = 0;
 	len = g_mime_utils_base64_encode_close (digest, 16, b64digest, &state, &save);
 	b64digest[len] = '\0';
-	g_strstrip ((char *) b64digest);
+	g_strstrip (b64digest);
 	
-	return !strcmp ((char *) b64digest, mime_part->content_md5);
+	return !strcmp (b64digest, mime_part->content_md5);
 }
 
 
@@ -776,9 +764,6 @@ g_mime_part_get_content_location (GMimePart *mime_part)
  * @mime_type: Mime content-type
  *
  * Set the content type/subtype for the specified mime part.
- *
- * WARNING: This interface is deprecated. Use
- * g_mime_object_set_content_type().
  **/
 void
 g_mime_part_set_content_type (GMimePart *mime_part, GMimeContentType *mime_type)
@@ -797,9 +782,6 @@ g_mime_part_set_content_type (GMimePart *mime_part, GMimeContentType *mime_type)
  * Gets the Content-Type object for the given mime part or %NULL on
  * error.
  *
- * WARNING: This interface is deprecated. Use
- * g_mime_object_get_content_type().
- *
  * Returns the content-type object for the specified mime part.
  **/
 const GMimeContentType *
@@ -918,8 +900,6 @@ g_mime_part_encoding_from_string (const char *encoding)
 		return GMIME_PART_ENCODING_BASE64;
 	else if (!g_ascii_strcasecmp (encoding, "quoted-printable"))
 		return GMIME_PART_ENCODING_QUOTEDPRINTABLE;
-	else if (!g_ascii_strcasecmp (encoding, "uuencode"))
-		return GMIME_PART_ENCODING_UUENCODE;
 	else if (!g_ascii_strcasecmp (encoding, "x-uuencode"))
 		return GMIME_PART_ENCODING_UUENCODE;
 	else
@@ -1292,22 +1272,22 @@ g_mime_part_get_content (const GMimePart *mime_part, size_t *len)
 		g_object_unref (cache);
 		
 		*len = buf->len;
-		retval = (char *) buf->data;
+		retval = buf->data;
 	} else {
 		GByteArray *buf = GMIME_STREAM_MEM (stream)->buffer;
-		off_t end_index = (off_t) buf->len;
-		off_t start_index = 0;
+		int start_index = 0;
+		int end_index = buf->len;
 		
 		/* check boundaries */
 		if (stream->bound_start >= 0)
-			start_index = CLAMP (stream->bound_start, 0, (off_t) buf->len);
+			start_index = CLAMP (stream->bound_start, 0, buf->len);
 		if (stream->bound_end >= 0)
-			end_index = CLAMP (stream->bound_end, 0, (off_t) buf->len);
+			end_index = CLAMP (stream->bound_end, 0, buf->len);
 		if (end_index < start_index)
 			end_index = start_index;
 		
 		*len = end_index - start_index;
-		retval = (char *) buf->data + start_index;
+		retval = buf->data + start_index;
 	}
 	
 	return retval;
