@@ -1,21 +1,20 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public License
- *  as published by the Free Software Foundation; either version 2.1
- *  of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This library is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free
- *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -29,17 +28,6 @@
 
 #define d(x)
 
-
-/**
- * SECTION: gmime-stream-cat
- * @title: GMimeStreamCat
- * @short_description: A concatenated stream
- * @see_also: #GMimeStream
- *
- * A #GMimeStream which chains together any number of other streams.
- **/
-
-
 static void g_mime_stream_cat_class_init (GMimeStreamCatClass *klass);
 static void g_mime_stream_cat_init (GMimeStreamCat *stream, GMimeStreamCatClass *klass);
 static void g_mime_stream_cat_finalize (GObject *object);
@@ -162,6 +150,11 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 		return -1;
 	
 	do {
+		/* make sure our stream position is where it should be */
+		offset = current->stream->bound_start + current->position;
+		if (g_mime_stream_seek (current->stream, offset, GMIME_STREAM_SEEK_SET) == -1)
+			return -1;
+		
 		if ((nread = g_mime_stream_read (current->stream, buf, len)) <= 0) {
 			cat->current = current = current->next;
 			if (current != NULL) {
@@ -186,8 +179,7 @@ stream_write (GMimeStream *stream, const char *buf, size_t len)
 {
 	GMimeStreamCat *cat = (GMimeStreamCat *) stream;
 	struct _cat_node *current;
-	size_t nwritten = 0;
-	ssize_t n = -1;
+	ssize_t nwritten = 0, n = -1;
 	off_t offset;
 	
 	/* check for end-of-stream */
@@ -234,10 +226,7 @@ stream_write (GMimeStream *stream, const char *buf, size_t len)
 	
 	cat->current = current;
 	
-	if (n == -1 && nwritten == 0)
-		return -1;
-	
-	return nwritten;
+	return n == -1 && nwritten == 0 ? -1 : nwritten;
 }
 
 static int
@@ -422,8 +411,7 @@ stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
 			}
 			
 			/* after our current position */
-			d(fprintf (stderr, "after cur position in stream[%d] or in a later stream\n",
-				   current->id));
+			d(fprintf (stderr, "after cur position in stream[%d] or in a later stream\n"));
 			do {
 				if (current->stream->bound_end != -1) {
 					len = current->stream->bound_end - current->stream->bound_start;
@@ -442,7 +430,7 @@ stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
 					break;
 				} else {
 					d(fprintf (stderr, "not within bounds of stream[%d]\n",
-						   current->id));
+						   current->id, len));
 					current->position = len;
 					real += len;
 					
@@ -638,24 +626,35 @@ stream_substream (GMimeStream *stream, off_t start, off_t end)
 		n = n->next;
 	} while (n != NULL);
 	
-	d(fprintf (stderr, "returning a substream containing multiple source streams\n"));
-	cat = g_object_new (GMIME_TYPE_STREAM_CAT, NULL);
-	/* Note: we could pass -1 as bound_end, it should Just
-	 * Work(tm) but setting absolute bounds is kinda
-	 * nice... */
-	g_mime_stream_construct (GMIME_STREAM (cat), 0, subend);
-	
-	while (streams != NULL) {
-		s = streams->next;
-		substream = g_mime_stream_substream (streams->stream, streams->start, streams->end);
-		g_mime_stream_cat_add_source (cat, substream);
-		g_object_unref (substream);
-		g_free (streams);
-		streams = s;
+	if (s == streams) {
+		d(fprintf (stderr, "returning stream[%d]::substream (%ld, %ld)\n",
+			   n->id, s->start, s->end));
+		substream = g_mime_stream_substream (s->stream, s->start, s->end);
+		while (streams != NULL) {
+			s = streams->next;
+			g_free (streams);
+			streams = s;
+		}
+	} else {
+		d(fprintf (stderr, "returning a substream containing multiple source streams\n"));
+		cat = g_object_new (GMIME_TYPE_STREAM_CAT, NULL);
+		/* Note: we could pass -1 as bound_end, it should Just
+		 * Work(tm) but setting absolute bounds is kinda
+		 * nice... */
+		g_mime_stream_construct (GMIME_STREAM (cat), 0, subend);
+		
+		while (streams != NULL) {
+			s = streams->next;
+			substream = g_mime_stream_substream (streams->stream, streams->start, streams->end);
+			g_mime_stream_cat_add_source (cat, substream);
+			g_object_unref (substream);
+			g_free (streams);
+			streams = s;
+		}
+		
+		substream = (GMimeStream *) cat;
 	}
 	
-	substream = (GMimeStream *) cat;
-	
 	return substream;
 	
  error:
@@ -682,7 +681,7 @@ g_mime_stream_cat_new (void)
 {
 	GMimeStreamCat *cat;
 	
-	cat = g_object_new (GMIME_TYPE_STREAM_CAT, NULL);
+	cat = g_object_new (GMIME_TYPE_STREAM_CAT, NULL, NULL);
 	
 	g_mime_stream_construct (GMIME_STREAM (cat), 0, -1);
 	
