@@ -1,21 +1,20 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public License
- *  as published by the Free Software Foundation; either version 2.1
- *  of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This library is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free
- *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -27,23 +26,6 @@
 
 #include "gmime-stream-filter.h"
 
-
-/**
- * SECTION: gmime-stream-filter
- * @title: GMimeStreamFilter
- * @short_description: A filtering stream
- * @see_also: #Filters
- *
- * A #GMimeStream meant for filtering data passing through it.
- *
- * This stream class is useful for converting data of one type to
- * another using #GMimeFilter objects.
- *
- * When data passes through a #GMimeStreamFilter, it will pass through
- * #GMimeFilter filters in the order they were added.
- **/
-
-
 #define READ_PAD (64)		/* bytes padded before buffer */
 #define READ_SIZE (4096)
 
@@ -102,7 +84,7 @@ g_mime_stream_filter_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimeStreamFilter),
-			0,    /* n_preallocs */
+			16,   /* n_preallocs */
 			(GInstanceInitFunc) g_mime_stream_filter_init,
 		};
 		
@@ -252,7 +234,7 @@ stream_write (GMimeStream *stream, const char *buf, size_t n)
 		f = f->next;
 	}
 	
-	if (g_mime_stream_write (filter->source, buffer, n) == -1)
+	if (g_mime_stream_write (filter->source, buffer, n) != n)
 		return -1;
 	
 	/* return original input len because that's what our caller expects */
@@ -324,9 +306,6 @@ stream_reset (GMimeStream *stream)
 	struct _GMimeStreamFilterPrivate *priv = filter->priv;
 	struct _filter *f;
 	
-	if (g_mime_stream_reset (filter->source) == -1)
-		return -1;
-	
 	priv->filteredlen = 0;
 	priv->flushed = FALSE;
 	
@@ -337,7 +316,7 @@ stream_reset (GMimeStream *stream)
 		f = f->next;
 	}
 	
-	return 0;
+	return g_mime_stream_reset (filter->source);
 }
 
 static off_t
@@ -414,7 +393,7 @@ g_mime_stream_filter_new_with_stream (GMimeStream *stream)
 	
 	g_return_val_if_fail (GMIME_IS_STREAM (stream), NULL);
 	
-	filter = g_object_new (GMIME_TYPE_STREAM_FILTER, NULL);
+	filter = g_object_new (GMIME_TYPE_STREAM_FILTER, NULL, NULL);
 	filter->source = stream;
 	g_object_ref (stream);
 	
