@@ -1,21 +1,20 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public License
- *  as published by the Free Software Foundation; either version 2.1
- *  of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This library is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free
- *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
- *  02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -27,18 +26,6 @@
 
 #include "gmime-stream-mem.h"
 
-
-/**
- * SECTION: gmime-stream-mem
- * @title: GMimeStreamMem
- * @short_description: A memory-backed stream
- * @see_also: #GMimeStream
- *
- * A simple #GMimeStream implementation that uses a memory buffer for
- * storage.
- **/
-
-
 static void g_mime_stream_mem_class_init (GMimeStreamMemClass *klass);
 static void g_mime_stream_mem_init (GMimeStreamMem *stream, GMimeStreamMemClass *klass);
 static void g_mime_stream_mem_finalize (GObject *object);
@@ -72,7 +59,7 @@ g_mime_stream_mem_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimeStreamMem),
-			0,    /* n_preallocs */
+			16,   /* n_preallocs */
 			(GInstanceInitFunc) g_mime_stream_mem_init,
 		};
 		
@@ -133,7 +120,7 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 	
 	g_return_val_if_fail (mem->buffer != NULL, -1);
 	
-	bound_end = stream->bound_end != -1 ? stream->bound_end : (off_t) mem->buffer->len;
+	bound_end = stream->bound_end != -1 ? stream->bound_end : mem->buffer->len;
 	
 	n = MIN (bound_end - stream->position, (off_t) len);
 	if (n > 0) {
@@ -203,7 +190,7 @@ stream_eos (GMimeStream *stream)
 	
 	g_return_val_if_fail (mem->buffer != NULL, TRUE);
 	
-	bound_end = stream->bound_end != -1 ? stream->bound_end : (off_t) mem->buffer->len;
+	bound_end = stream->bound_end != -1 ? stream->bound_end : mem->buffer->len;
 	
 	return stream->position >= bound_end;
 }
@@ -224,7 +211,7 @@ stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
 	
 	g_return_val_if_fail (mem->buffer != NULL, -1);
 	
-	bound_end = stream->bound_end != -1 ? stream->bound_end : (off_t) mem->buffer->len;
+	bound_end = stream->bound_end != -1 ? stream->bound_end : mem->buffer->len;
 	
 	switch (whence) {
 	case GMIME_STREAM_SEEK_SET:
@@ -266,7 +253,7 @@ stream_length (GMimeStream *stream)
 	
 	g_return_val_if_fail (mem->buffer != NULL, -1);
 	
-	bound_end = stream->bound_end != -1 ? stream->bound_end : (off_t) mem->buffer->len;
+	bound_end = stream->bound_end != -1 ? stream->bound_end : mem->buffer->len;
 	
 	return bound_end - stream->bound_start;
 }
@@ -276,7 +263,7 @@ stream_substream (GMimeStream *stream, off_t start, off_t end)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
+	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL, NULL);
 	mem->owner = FALSE;
 	mem->buffer = GMIME_STREAM_MEM (stream)->buffer;
 	
@@ -298,9 +285,9 @@ g_mime_stream_mem_new (void)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
-	mem->buffer = g_byte_array_new ();
+	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL, NULL);
 	mem->owner = TRUE;
+	mem->buffer = g_byte_array_new ();
 	
 	g_mime_stream_construct (GMIME_STREAM (mem), 0, -1);
 	
@@ -321,7 +308,7 @@ g_mime_stream_mem_new_with_byte_array (GByteArray *array)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
+	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL, NULL);
 	mem->owner = TRUE;
 	mem->buffer = array;
 	
@@ -346,11 +333,11 @@ g_mime_stream_mem_new_with_buffer (const char *buffer, size_t len)
 {
 	GMimeStreamMem *mem;
 	
-	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL);
+	mem = g_object_new (GMIME_TYPE_STREAM_MEM, NULL, NULL);
 	mem->owner = TRUE;
 	mem->buffer = g_byte_array_new ();
 	
-	g_byte_array_append (mem->buffer, (unsigned char *) buffer, len);
+	g_byte_array_append (mem->buffer, buffer, len);
 	
 	g_mime_stream_construct (GMIME_STREAM (mem), 0, -1);
 	
@@ -393,7 +380,7 @@ g_mime_stream_mem_set_byte_array (GMimeStreamMem *mem, GByteArray *array)
 	g_return_if_fail (GMIME_IS_STREAM_MEM (mem));
 	g_return_if_fail (array != NULL);
 	
-	if (mem->owner && mem->buffer)
+	if (mem->buffer)
 		g_byte_array_free (mem->buffer, TRUE);
 	
 	mem->buffer = array;
