@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 1999-2006 Jeffrey Stedfast
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -301,7 +301,7 @@ internet_address_get_addr (InternetAddress *ia)
  * internet_address_get_members:
  * @ia: internet address
  *
- * Returns the list of internet addresses
+ * Returns the list of internet addresses.
  **/
 const InternetAddressList *
 internet_address_get_members (InternetAddress *ia)
@@ -421,9 +421,9 @@ internet_address_list_concat (InternetAddressList *a, InternetAddressList *b)
  * internet_address_list_next:
  * @list: list of internet addresses
  *
- * Advances to the next address node in the InternetAddessList.
+ * Advances to the next address node in the #InternetAddessList.
  *
- * Returns the next address node in the InternetAddessList.
+ * Returns the next address node in the #InternetAddessList.
  **/
 InternetAddressList *
 internet_address_list_next (const InternetAddressList *list)
@@ -436,15 +436,14 @@ internet_address_list_next (const InternetAddressList *list)
  * internet_address_list_get_address:
  * @list: list of internet addresses
  *
+ * Gets the #InternetAddress currently pointed to in @list.
+ *
  * Returns the #InternetAddress currently pointed to in @list.
  **/
 InternetAddress *
 internet_address_list_get_address (const InternetAddressList *list)
 {
-	if (!list)
-		return NULL;
-
-	return list->address;
+	return list ? list->address : NULL;
 }
 
 /**
