@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2002 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -42,7 +39,7 @@
 #define PRINT_MIME_STRUCT
 /*#define TEST_WRITE_TO_STREAM*/
 
-void
+static void
 print_depth (int depth)
 {
 	int i;
@@ -51,7 +48,7 @@ print_depth (int depth)
 		fprintf (stdout, "   ");
 }
 
-void
+static void
 print_mime_struct (GMimeObject *part, int depth)
 {
 	const GMimeContentType *type;
@@ -85,7 +82,7 @@ print_mime_struct (GMimeObject *part, int depth)
 	}
 }
 
-void
+static void
 test_parser (GMimeStream *stream)
 {
 	GMimeParser *parser;
@@ -186,8 +183,7 @@ int main (int argc, char **argv)
 	else
 		return 0;
 	
-	fd = open (filename, O_RDONLY);
-	if (fd == -1)
+	if ((fd = open (filename, O_RDONLY)) == -1)
 		return 0;
 	
 #ifdef STREAM_MMAP
